@@ -13,7 +13,7 @@ class DateTool(object):
         """获取当前月份范围"""
         year = datetime.datetime.now().year
         month = datetime.datetime.now().month
-        return get_first_and_last_day(year, month)
+        return self.get_first_and_last_day(year, month)
 
     @classmethod
     def get_first_and_last_day(self, year, month):
